@@ -1,7 +1,4 @@
 #!/bin/sh
-
-# $Id: install_rrdtool.sh,v 1.6 2006/12/20 20:59:14 dijkstra Exp $
-#
 # Script to install rrdtool inside apache chroot
 
 RRD_CMD=${RRD_CMD:-/usr/local/bin/rrdtool}
@@ -31,10 +28,27 @@ if [ "${LIBS}x" = x ]; then
 fi
 
 cd ${PREFIX}
-mkdir -p bin usr/lib usr/libexec
-cp -f $LIBS usr/lib
+for lib in ${LIBS}; do
+    libdir=`dirname ${lib}`
+    mkdir -p ${PREFIX}${libdir}
+    cp ${lib} ${PREFIX}${libdir}
+done
+
+mkdir -p bin usr/lib usr/libexec var/run usr/local/share/fonts etc/fonts
 cp -f ${RRD_CMD} bin
 cp -f /usr/libexec/ld.so usr/libexec
 cp -f /bin/sh bin/sh
-echo rrdtool and libs installed in apache root
-exit 1
+cp -f cp /usr/X11R6/lib/X11/fonts/TTF/DejaVuSansMono* usr/local/share/fonts
+cat >etc/fonts/fonts.conf <<EOF
+<?xml version="1.0"?>
+<!DOCTYPE fontconfig SYSTEM "urn:fontconfig:fonts.dtd">
+<fontconfig>
+	<description>Minimal configuration file</description>
+	<dir>/usr/local/share/fonts</dir>
+</fontconfig>
+EOF
+chown www:daemon var/run
+cp /sbin/ldconfig bin/ldconfig
+chroot -u www /var/www ldconfig /usr/lib /usr/local/lib /usr/X11R6/lib
+rm bin/ldconfig
+echo rrdtool, fonts and libs installed in apache root
